@@ -4,9 +4,7 @@ use crate::lib::{
     String, ToString, Vec,
 };
 use core::ops::Deref;
-use rand::distributions::Standard;
-use rand::prelude::Distribution;
-use rand::Rng;
+use rand::{distributions::Standard, prelude::Distribution, random, Rng};
 use serde::{Deserialize, Serialize};
 
 /// A collection of Addresses
@@ -81,6 +79,14 @@ pub struct Address {
 }
 
 impl Address {
+    /// Create a new address from separate type and data parts
+    pub fn new<S: Into<String>>(tt: u8, inner: S) -> Self {
+        Self {
+            tt,
+            inner: inner.into().as_bytes().to_vec(),
+        }
+    }
+
     /// Parse an address from a string
     ///
     /// See type documentation for more detail
@@ -113,10 +119,7 @@ impl Address {
 
     /// Generate a random address with a specific type
     pub fn random(tt: u8) -> Self {
-        let mut rng = rand::thread_rng();
-        let address: [u8; 16] = rng.gen();
-        let inner = hex::encode(address).as_bytes().into();
-        Self { tt, inner }
+        Self { tt, ..random() }
     }
 }
 
